﻿using System;
using System.Diagnostics;
using Utils;

namespace WpfCommandsCsTutorial.ViewModels;

public class MainViewModel : PropertyChangedBase
{
    private string _user;

    public string User
    {
        get => _user;
        set
        {
            if (_user == value)
                return;
            _user = value;
            NotifyOfPropertyChange();
            LoginCommand.RaiseCanExecuteChanged();
        }
    }

    private string _password;

    public string Password
    {
        get => _password;
        set
        {
            if (_password == value)
                return;
            _password = value;
            NotifyOfPropertyChange();
            LoginCommand.RaiseCanExecuteChanged();
        }
    }

    public DelegateCommand LoginCommand { get; set; }

    private int _loginAttempts;

    public int LoginAttempts
    {
        get => _loginAttempts;
        set
        {
            _loginAttempts = value;
            LoginCommand.RaiseCanExecuteChanged();
        }
    }

    public MainViewModel()
    {
        _user = "";
        _password = "";
        LoginCommand = new DelegateCommand(Login, CanLogin);
    }

    private void Login(object? parameter)
    {
        // get the command parameter passed in by xaml with:
        // would now contain the 'D' passed from UI
        // var givenParam = Convert.ToString(parameter);

        Debug.WriteLine($"I will login with User: '{User}', Password: '{Password}'");
        // simulate failed login
        LoginAttempts += 1;
    }

    private bool CanLogin(object? parameter)
        => _loginAttempts < 3;
}
